# Pre-requisites
- Python 3.11 or higher.
- Ubuntu 22.04 or higher.
- Install the dependencies Ubuntu packages:
  ```bash
  sudo apt update &&
  sudo apt install -y translate-shell xclip libxcb-cursor-dev --upgrade
  ```
  
- Install required Python packages:
  ```bash
  pip install -r requirements.txt --upgrade
  ```